aboutsummaryrefslogtreecommitdiffstats
path: root/src/ui/widgets/SignersPicker.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/ui/widgets/SignersPicker.h (renamed from include/ui/widgets/SignersPicker.h)24
1 files changed, 12 insertions, 12 deletions
diff --git a/include/ui/widgets/SignersPicker.h b/src/ui/widgets/SignersPicker.h
index afa95a05..055b6ef6 100644
--- a/include/ui/widgets/SignersPicker.h
+++ b/src/ui/widgets/SignersPicker.h
@@ -1,7 +1,7 @@
/**
* This file is part of GPGFrontend.
*
* GPGFrontend is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
@@ -27,22 +27,22 @@
#include "GpgFrontend.h"
#include "gpg/GpgContext.h"
-
#include "ui/widgets/KeyList.h"
-class SignersPicker : public QDialog {
-Q_OBJECT
+namespace GpgFrontend::UI {
-public:
+class SignersPicker : public QDialog {
+ Q_OBJECT
- explicit SignersPicker(GpgME::GpgContext *ctx, QWidget *parent = nullptr);
+ public:
+ explicit SignersPicker(QWidget* parent = nullptr);
- void getCheckedSigners(QVector<GpgKey> &keys);
+ GpgFrontend::KeyIdArgsListPtr getCheckedSigners();
-private:
- GpgME::GpgContext *mCtx;
- KeyList *mKeyList;
+ private:
+ KeyList* mKeyList;
};
+} // namespace GpgFrontend::UI
-#endif //GPGFRONTEND_ZH_CN_TS_SIGNERSPIRCKER_H
+#endif // GPGFRONTEND_ZH_CN_TS_SIGNERSPIRCKER_H
@@ -1,7 +1,7 @@
/**
- * This file is part of GPGFrontend.
+ * This file is part of GpgFrontend.
*
@@ -1,7 +1,7 @@
*
- * GPGFrontend is free software: you can redistribute it and/or modify
+ * GpgFrontend is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or